Module adapter

Module adapter 

Structs

Adapter
Staged builder root: pattern-first entry (Adapter::inbound().http()...).
HttpInboundAdapter
HttpInboundBuilder
HttpOutboundAdapter
HttpOutboundAdapterBuilder
InboundStage
OutboundDispatchResult
Metadata returned from outbound dispatch. Leave fields optional / expandable for future.
OutboundStage

Enums

Mep
Message Exchange Pattern for HTTP inbound.

Traits

BaseAdapter
Marker trait for all adapters (inbound or outbound). Intentionally empty so it can be used for blanket implementations of decoration layers. Do NOT add methods here unless they apply uniformly to both inbound and outbound adapters.
InboundAdapter
Inbound adapter: receives external data/events and produces Exchanges routed inside Allora.
InboundHttpExt
Extension trait adding .http() to the core InboundStage.
OutboundAdapter
Outbound adapter: sends data derived from an Exchange to an external system.
OutboundHttpExt
Extension trait adding .http() to the core OutboundStage.

Functions

ensure_correlation
Ensure a correlation_id header exists on the inbound message of the provided Exchange. Safe to call multiple times (id will be stable after first generation).