BaseAdapter

Trait BaseAdapter 

pub trait BaseAdapter:
    Send
    + Sync
    + Debug {
    // Required method
    fn id(&self) -> &str;
}
Marker trait for all adapters (inbound or outbound). Intentionally empty so it can be used for blanket implementations of decoration layers. Do NOT add methods here unless they apply uniformly to both inbound and outbound adapters.

Required Methods

fn id(&self) -> &str

Stable identifier for this adapter instance (user-assigned or generated).

Implementors