pub trait CompletionCondition: Send + Sync {
// Required method
fn is_complete(&self, group: &[Message], first_seen: Instant) -> bool;
}Expand description
Decides when an in-progress correlation group is complete.
Called after each message is appended to the group. Implementations should be cheap — they may be called on every inbound message.
Required Methods
Sourcefn is_complete(&self, group: &[Message], first_seen: Instant) -> bool
fn is_complete(&self, group: &[Message], first_seen: Instant) -> bool
Return true if group (the current accumulated messages, in arrival order) is complete.
first_seen is when the first message of this group arrived; useful for time-based conditions.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".