pub trait BaseAdapter:
Send
+ Sync
+ Debug {
// Required method
fn id(&self) -> &str;
}Expand description
Marker trait for all adapters (inbound or outbound). Intentionally empty so it can be used for blanket implementations of decoration layers. Do NOT add methods here unless they apply uniformly to both inbound and outbound adapters.