pub struct QueueChannel { /* private fields */ }Implementations
Sourceimpl QueueChannel
impl QueueChannel
Sourcepub fn with_id<S>(id: S) -> QueueChannel
pub fn with_id<S>(id: S) -> QueueChannel
Create a new queue channel with an explicit identifier.
Sourcepub fn with_random_id() -> QueueChannel
pub fn with_random_id() -> QueueChannel
Create a new queue channel with a randomly generated UUID-based identifier.