pub struct AlloraSpec { /* private fields */ }Implementations
Sourceimpl AlloraSpec
impl AlloraSpec
pub fn new(version: u32, channels: ChannelsSpec) -> Self
Sourcepub fn new_with_filters(
version: u32,
channels: ChannelsSpec,
filters: Option<FiltersSpec>,
) -> Self
pub fn new_with_filters( version: u32, channels: ChannelsSpec, filters: Option<FiltersSpec>, ) -> Self
Construct with an optional filters collection in a single call (ergonomic alternative to chaining with_filters).
When filters is None, behaves the same as new.
pub fn with_filters(self, filters: FiltersSpec) -> Self
pub fn with_services(self, services: ServiceActivatorsSpec) -> Self
pub fn with_http_inbound_adapters( self, adapters: HttpInboundAdaptersSpec, ) -> Self
pub fn with_http_outbound_adapters( self, adapters: HttpOutboundAdaptersSpec, ) -> Self
pub fn version(&self) -> u32
pub fn channels_spec(&self) -> &ChannelsSpec
pub fn filters_spec(&self) -> Option<&FiltersSpec>
pub fn services_spec(&self) -> Option<&ServiceActivatorsSpec>
pub fn http_inbound_adapters_spec(&self) -> Option<&HttpInboundAdaptersSpec>
pub fn http_outbound_adapters_spec(&self) -> Option<&HttpOutboundAdaptersSpec>
pub fn into_channels_spec(self) -> ChannelsSpec
pub fn into_filters_spec(self) -> Option<FiltersSpec>
pub fn into_services_spec(self) -> Option<ServiceActivatorsSpec>
pub fn into_http_inbound_adapters_spec(self) -> Option<HttpInboundAdaptersSpec>
pub fn into_http_outbound_adapters_spec( self, ) -> Option<HttpOutboundAdaptersSpec>